==> kdesvn-1.7.0.tar.xz: kdesvn-1.7.0/src/commandline.h <==
/***************************************************************************
 *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef COMMANDLINE_H
#define COMMANDLINE_H

#include <QObject>

class KCmdLineArgs;
class CommandLineData;

/**
@author Rajko Albrecht
*/
class CommandLine: public QObject
{
    Q_OBJECT
public:
    explicit CommandLine(KCmdLineArgs *);
    virtual ~CommandLine();

    virtual int exec();

protected:
    KCmdLineArgs *m_args;
    CommandLineData *m_data;
};

#endif

==> kdesvn_2.1.0.orig.tar.xz: kdesvn-2.1.0/src/commandline.h <==
/***************************************************************************
 *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#pragma once

#include <QString>

class QCommandLineParser;

/**
@author Rajko Albrecht
*/
class CommandLine
{
public:
    explicit CommandLine(const QCommandLineParser *parser);
    ~CommandLine();

    int exec();

protected:
    void displayHelp();
    const QCommandLineParser *m_parser;
    QString cmd;
};
